3.3. Metadata — CubicWeb 3.11.0

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Repository development »
- 3. Data model »

# 3.3. Metadata

Each entity type in CubicWeb has at least the following meta-data attributes and relations:

eid
  entity’s identifier which is unique in an instance. We usually call this identifier eid for historical reason.
creation_date
  Date and time of the creation of the entity.
modification_date
  Date and time of the latest modification of an entity.
cwuri
  Reference URL of the entity, which is not expected to change.
created_by
  Relation to the users who has created the entity
owned_by
  Relation to users whom the entity belongs; usually the creator but not necessary, and it could have multiple owners notably for permission control
is
  Relation to the entity type of which type the entity is.
is_instance
  Relation to the entity types of which type the entity is an instance of.

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.11.0 »
- Repository development »
- 3. Data model »